FluentBitContainerSecurityContextAppArmorProfile

Struct FluentBitContainerSecurityContextAppArmorProfile 

pub struct FluentBitContainerSecurityContextAppArmorProfile {
    pub localhost_profile: Option<String>,
    pub type: String,
}
appArmorProfile is the AppArmor options to use by this container. If set, this profile overrides the pod’s appArmorProfile. Note that this field cannot be set when spec.os.name is windows.

Fields

localhost_profile: Option<String>

localhostProfile indicates a profile loaded on the node that should be used. The profile must be preconfigured on the node to work. Must match the loaded name of the profile. Must be set if and only if type is “Localhost”.

type: String

type indicates which kind of AppArmor profile will be applied. Valid options are: Localhost - a profile pre-loaded on the node. RuntimeDefault - the container runtime’s default profile. Unconfined - no AppArmor enforcement.