pub struct FluentBitPositionDbFlexVolume {
pub driver: String,
pub fs_type: Option<String>,
pub options: Option<BTreeMap<String, String>>,
pub read_only: Option<bool>,
pub secret_ref: Option<FluentBitPositionDbFlexVolumeSecretRef>,
}Expand description
flexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. Deprecated: FlexVolume is deprecated. Consider using a CSIDriver instead.
Fields
driver: Stringdriver is the name of the driver to use for this volume.
fs_type: Option<String>fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. The default filesystem depends on FlexVolume script.
options: Option<BTreeMap<String, String>>options is Optional: this field holds extra command options if any.
read_only: Option<bool>readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
secret_ref: Option<FluentBitPositionDbFlexVolumeSecretRef>secretRef is Optional: secretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.