pub struct FluentBitPositionDbFlocker {
pub dataset_name: Option<String>,
pub dataset_uuid: Option<String>,
}Expand description
flocker represents a Flocker volume attached to a kubelet’s host machine. This depends on the Flocker control service being running. Deprecated: Flocker is deprecated and the in-tree flocker type is no longer supported.
Fields
dataset_name: Option<String>datasetName is Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated
dataset_uuid: Option<String>datasetUUID is the UUID of the dataset. This is unique identifier of a Flocker dataset