pub struct FluentBitPositionDbGlusterfs {
pub endpoints: String,
pub path: String,
pub read_only: Option<bool>,
}Expand description
glusterfs represents a Glusterfs mount on the host that shares a pod’s lifetime. Deprecated: Glusterfs is deprecated and the in-tree glusterfs type is no longer supported.
Fields
endpoints: Stringendpoints is the endpoint name that details Glusterfs topology.
path: Stringpath is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod
read_only: Option<bool>readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod