pub struct OutputInfluxDbHttpPasswordValueFromSecretKeyRef {
pub key: String,
pub name: Option<String>,
pub optional: Option<bool>,
}Expand description
Selects a key of a secret in the pod’s namespace
Fields
key: StringThe key of the secret to select from. Must be a valid secret key.
name: Option<String>Name of the referent. This field is effectively required, but due to backwards compatibility is allowed to be empty. Instances of this type with an empty value here are almost certainly wrong. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
optional: Option<bool>Specify whether the Secret or its key must be defined